@@ -1,18 +1,8 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 # nolint start
-knitr::opts_chunk$set(
-  echo = TRUE,
-  message = FALSE,
-  warning = FALSE,
-  collapse = TRUE,
-  comment = "#>"
-)
-if (.Platform$OS.type == "windows") {
-  # due to corrupt rds-file from dataquieR package
-  knitr::opts_chunk$set(eval = FALSE)
-}
 library(magrittr)
 
+
 ## -----------------------------------------------------------------------------
 # the next lines are commentend, since we avoided to have 'dataquieR' as yet
 # another dependency to our package; however, if you have installed it, you
@@ -25,17 +15,13 @@ library(magrittr)
 #   system.file("extdata/ship.RDS", package = "dataquieR")
 # ) %>%
 #   data.table::data.table()
-ship_fn <- file.path(tempdir(), "ship.RDS")
 ship_url <- paste0(
   "https://raw.githubusercontent.com/cran/dataquieR/",
   "master/inst/extdata/ship.RDS"
 )
-download.file(
-  url = ship_url,
-  destfile = ship_fn
-)
-Sys.sleep(1)
-ship_data <- readRDS(ship_fn) %>%
+tmpf <- tempfile()
+download.file(ship_url, tmpf, mode = "wb")
+ship_data <- readRDS(tmpf) %>%
   data.table::data.table()
 
 # export the dataset to a CSV-file (one of the formats supported by DQAstats)
@@ -45,25 +31,23 @@ data.table::fwrite(
   file = file.path(tempdir(), ship_data_export_fn)
 )
 
+
 ## -----------------------------------------------------------------------------
 # load the ship metadata
 # ship_meta <- readRDS(
 #   system.file("extdata/ship_meta.RDS", package = "dataquieR")
 # ) %>%
 #   data.table::data.table()
-ship_meta_fn <- file.path(tempdir(), "ship_meta.RDS")
 ship_meta_url <- paste0(
   "https://raw.githubusercontent.com/cran/dataquieR/",
   "master/inst/extdata/ship_meta.RDS"
 )
-download.file(
-  url = ship_meta_url,
-  destfile = ship_meta_fn
-)
-Sys.sleep(1)
-ship_meta <- readRDS(ship_meta_fn) %>%
+tmpf <- tempfile()
+download.file(ship_meta_url, tmpf, mode = "wb")
+ship_meta <- readRDS(tmpf) %>%
   data.table::data.table()
 
+
 ## ----results='asis'-----------------------------------------------------------
 ship_meta %>%
   DT::datatable(options = list(
@@ -71,6 +55,7 @@ ship_meta %>%
     pageLength = 4
   ))
 
+
 ## -----------------------------------------------------------------------------
 mdr <- data.table::fread(
   file = system.file(
@@ -84,9 +69,10 @@ mdr <- data.table::fread(
 dim(mdr)
 colnames(mdr)
 
+
 ## ----warning=FALSE------------------------------------------------------------
 # get names of dataelements from ship dataset
-ship_var_names <- colnames(ship_data)
+ship_var_names <- intersect(colnames(ship_data), ship_meta[, get("VAR_NAMES")])
 
 # loop over dataelements
 for (var in ship_var_names) {
@@ -132,6 +118,7 @@ for (var in ship_var_names) {
   )
 }
 
+
 ## -----------------------------------------------------------------------------
 # save all categorical variablees in a vector
 cat_vars <- c(
@@ -144,6 +131,7 @@ cat_vars <- c(
 # results from DQAstats)
 mdr[get("designation") %in% cat_vars, ("variable_type") := "enumerated"]
 
+
 ## ----warning=FALSE------------------------------------------------------------
 # loop over categorical variables
 for (var in cat_vars) {
@@ -178,17 +166,20 @@ for (var in cat_vars) {
   mdr[get("source_variable_name") == var, ("constraints") := c]
 }
 
+
 ## -----------------------------------------------------------------------------
 # for comparison, show metadata definition from dataquieR ...
 # dataquieR: string, split by pipes '|'
 ship_meta[get("VAR_NAMES") == "smoking", get("VALUE_LABELS")]
 
+
 ## -----------------------------------------------------------------------------
 # ... and DQAstats: JSON
 mdr[get("source_variable_name") == "smoking", get("constraints")]
 mdr[get("source_variable_name") == "smoking", get("constraints")] %>%
   jsonlite::fromJSON()
 
+
 ## -----------------------------------------------------------------------------
 # get names of continuous variables (float/integer)
 cont_vars <- mdr[
@@ -236,6 +227,7 @@ for (var in cont_vars) {
   }
 }
 
+
 ## -----------------------------------------------------------------------------
 # The `id` variable should actually not be treated as a categorical variable,
 # since the number of potential categories is (theoretically) unlimited and
@@ -255,6 +247,7 @@ mdr[get("source_variable_name") == "id", ("constraints") := jsonlite::toJSON(
   auto_unbox = TRUE
 )]
 
+
 ## -----------------------------------------------------------------------------
 # add plausibilities
 # sex and contraception
@@ -286,6 +279,7 @@ mdr[
   plausibility_relation := p
 ]
 
+
 ## -----------------------------------------------------------------------------
 p <- jsonlite::toJSON(list(
   "atemporal" = list(
@@ -312,6 +306,7 @@ mdr[
   plausibility_relation := p
 ]
 
+
 ## -----------------------------------------------------------------------------
 p <- jsonlite::toJSON(list(
   "uniqueness" = list(
@@ -330,6 +325,7 @@ mdr[
   plausibility_relation := p
 ]
 
+
 ## ----results='asis'-----------------------------------------------------------
 mdr %>%
   DT::datatable(options = list(
@@ -337,6 +333,7 @@ mdr %>%
     pageLength = 4
   ))
 
+
 ## ----message=FALSE------------------------------------------------------------
 utils_path <- file.path(tempdir(), "utilities")
 dir.create(file.path(utils_path, "MDR"), recursive = TRUE)
@@ -346,6 +343,7 @@ data.table::fwrite(
   file = file.path(utils_path, "MDR/mdr.csv")
 )
 
+
 ## ----results='hide'-----------------------------------------------------------
 file.copy(
   from = system.file("demo_data/utilities/RMD", package = "DQAstats"),
@@ -354,39 +352,41 @@ file.copy(
   recursive = TRUE
 )
 
+
 ## ----eval=FALSE, warning=FALSE, message=FALSE---------------------------------
-#  # ship data set
-#  source_system_name <- "ship"
-#  target_system_name <- source_system_name
-#  
-#  mdr_filename <- "mdr.csv"
-#  output_dir <- file.path(tempdir(), "output")
-#  logfile_dir = tempdir()
-#  
-#  # does only work, if "ship_data.csv" is lying next to this RMD-file
-#  Sys.setenv("SHIP_PATH" = tempdir())
-#  
-#  # provide all arguments to main function
-#  all_results <- DQAstats::dqa(
-#    source_system_name = source_system_name,
-#    target_system_name = target_system_name,
-#    utils_path = utils_path,
-#    mdr_filename = mdr_filename,
-#    output_dir = output_dir,
-#    logfile_dir = logfile_dir,
-#    parallel = FALSE
-#  )
+## # ship data set
+## source_system_name <- "ship"
+## target_system_name <- source_system_name
+## 
+## mdr_filename <- "mdr.csv"
+## output_dir <- file.path(tempdir(), "output")
+## logfile_dir = tempdir()
+## 
+## # does only work, if "ship_data.csv" is lying next to this RMD-file
+## Sys.setenv("SHIP_PATH" = tempdir())
+## 
+## # provide all arguments to main function
+## all_results <- DQAstats::dqa(
+##   source_system_name = source_system_name,
+##   target_system_name = target_system_name,
+##   utils_path = utils_path,
+##   mdr_filename = mdr_filename,
+##   output_dir = output_dir,
+##   logfile_dir = logfile_dir,
+##   parallel = FALSE
+## )
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  library(DQAgui)
-#  # set basepath for file-browser in GUI-config
-#  Sys.setenv("CSV_SOURCE_BASEPATH" = tempdir())
-#  
-#  ## launch GUI
-#  DQAgui::launch_app(
-#    utils_path = utils_path,
-#    mdr_filename = "mdr.csv",
-#    parallel = FALSE
-#  )
-#  # nolint end
+## library(DQAgui)
+## # set basepath for file-browser in GUI-config
+## Sys.setenv("CSV_SOURCE_BASEPATH" = tempdir())
+## 
+## ## launch GUI
+## DQAgui::launch_app(
+##   utils_path = utils_path,
+##   mdr_filename = "mdr.csv",
+##   parallel = FALSE
+## )
+## # nolint end
 
