@@ -43,16 +43,7 @@ test_that("correct functioning of DQA", {
   )
 
   expect_type(all_results, "list")
-  expect_length(all_results, 27)
-
-  if (tinytex::is_tinytex()) {
-
-    outputfiles <- list.files(output_dir)
-    expect_true("DQA_report.md" %in% outputfiles)
-    expect_true(any(grepl("^DQA_report_([[:digit:]])+.pdf$", outputfiles)))
-    expect_true(any(grepl("^DQA_report_([[:digit:]])+.tex$", outputfiles)))
-
-  }
+  expect_length(all_results, 28)
 
   # Remove the settings and output-folder:
   do.call(file.remove, list(list.files(
